@@ -219,6 +219,10 @@ sub _on_child_signal {
     delete $heap->{wheels}{ $child->ID };
 }
 
+no Moose;
+
+__PACKAGE__->meta->make_immutable;
+
 =head1 AUTHOR
 
 Johannes Plunien E<lt>plu@cpan.orgE<gt>
