@@ -13,7 +13,7 @@ Gearman::Driver::Observer - Observes Gearman status interface
 Each n seconds L<Net::Telnet::Gearman> is used to fetch status of
 free/running/busy workers from the Gearman server. L<Gearman::Driver>
 decides to fork more workers depending on the queue size and the
-MinProcesses/MaxProcesses attribute of the job methods.
+MinChilds/MaxChilds attribute of the job methods.
 
 Currently there's no public interface.
 
@@ -108,11 +108,14 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 AUTHOR
 
-See L<Gearman::Driver>.
+Johannes Plunien E<lt>plu@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-See L<Gearman::Driver>.
+Copyright 2009 by Johannes Plunien
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
@@ -120,20 +123,8 @@ See L<Gearman::Driver>.
 
 =item * L<Gearman::Driver>
 
-=item * L<Gearman::Driver::Adaptor>
-
-=item * L<Gearman::Driver::Console>
-
-=item * L<Gearman::Driver::Console::Basic>
-
-=item * L<Gearman::Driver::Console::Client>
-
 =item * L<Gearman::Driver::Job>
 
-=item * L<Gearman::Driver::Job::Method>
-
-=item * L<Gearman::Driver::Loader>
-
 =item * L<Gearman::Driver::Worker>
 
 =back
